@@ -5,7 +5,10 @@ import re
 
 
 class StoryRunner(object):
-    def __init__(self, story_text, output, colored, modules=(), language='en-us'):
+    def __init__(self, story_text, output, colored,
+                 modules=(), language='en-us',
+                 before_all=(), before_each=(),
+                 after_all=(), after_each=()):
         self._story_text = story_text
         self._output = output
         self._modules = modules
@@ -17,6 +20,10 @@ class StoryRunner(object):
         self._all_whens = {}
         self._all_thens = {}
         self._collect_steps()
+        self._before_all = before_all
+        self._before_each = before_each
+        self._after_all = after_all
+        self._after_each = after_each
 
     def _collect_steps(self):
         for module in self._modules:
@@ -30,6 +37,22 @@ class StoryRunner(object):
         story = self._parsed_story.get_stories()[0]
         return story.header
 
+    def _call_before_each_methods(self, namespace):
+        for before_meth in self._before_each:
+            before_meth(namespace)
+
+    def _call_before_all_methods(self, namespace):
+        for before_meth in self._before_all:
+            before_meth(namespace)
+
+    def _call_after_all_methods(self, namespace):
+        for after_meth in self._after_all:
+            after_meth(namespace)
+
+    def _call_after_each_methods(self, namespace):
+        for after_meth in self._after_each:
+            after_meth(namespace)
+
     def _get_pycukes_story(self):
         return type('PyCukesStory',
                     (Story,),
@@ -39,7 +62,11 @@ class StoryRunner(object):
                      'colored': self._colored,
                      'scenarios': [],
                      'template_color':'yellow',
-                     'language': self._language,})
+                     'language': self._language,
+                     'before_each': self._call_before_each_methods,
+                     'before_all': self._call_before_all_methods,
+                     'after_all': self._call_after_all_methods,
+                     'after_each': self._call_after_each_methods,})
 
     def run(self):
         scenarios = self._parsed_story.get_stories()[0].scenarios
@@ -58,9 +85,9 @@ class StoryRunner(object):
                     all_runner_steps = getattr(self, '_all_%ss' % step_name)
                     actual_scenario = (None, step_message, ())
                     for step_regex, (step_method, step_args) in all_runner_steps.items():
-                        msg_pattern = re.sub(TEMPLATE_PATTERN, r'(.+)', step_regex)
+                        msg_pattern = re.sub(TEMPLATE_PATTERN, r'(.*)', step_regex)
                         msg_pattern = re.escape(msg_pattern)
-                        msg_pattern = msg_pattern.replace(re.escape(r'(.+)'), r'(.+)')
+                        msg_pattern = msg_pattern.replace(re.escape(r'(.*)'), r'(.*)')
 
                         if re.match(msg_pattern, step_message):
                             actual_scenario = (step_method,
@@ -70,4 +97,4 @@ class StoryRunner(object):
                     scenario_steps.append(actual_scenario)
  
             self._pycukes_story.scenarios.append(new_scenario)
-        self._pycukes_story.run()
+        return self._pycukes_story.run()
